Documentation
¶
Overview ¶
Package lazyassets is a package that provides a simple way to manage assets in a web application.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var (
ErrNotFound = errors.New("not found")
)
Functions ¶
This section is empty.
Types ¶
type Server ¶
type Server struct {
*Storage
// PermalinkFiles is a function that returns true if the file should have a permalink
// If nil, AllFiles is used
PermalinkFiles TestFn
// CSSTransformFiles is a function that returns true if the file css file should be transformed
// If nil, AllFiles is used (meaning all css files)
CSSTransformFiles TestFn
// NextHandler is the next handler to call if the path is not found
// If nil, 404 Not found is returned
NextHandler http.Handler
}
type TestFn ¶
func OnlyAssets ¶
func OnlyAssets() TestFn
OnlyAssets will have permalinks for images, css and js files
func OnlyDirectories ¶
func OnlyMimeTypes ¶
func OnlySubDirectories ¶
func OnlySubDirectories() TestFn
Click to show internal directories.
Click to hide internal directories.